==> test-envelope-ui-0.0.32.tgz: package/es/layout/layout.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  * {\n    box-sizing: border-box;\n  }\n  #root, body, html {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n  }\n'], ['\n  * {\n    box-sizing: border-box;\n  }\n  #root, body, html {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  &&& {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n    display: flex;\n    flex-direction: column;\n    box-sizing: border-box;\n  }\n'], ['\n  &&& {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n    display: flex;\n    flex-direction: column;\n    box-sizing: border-box;\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import styled, { createGlobalStyle, ThemeContext } from 'styled-components';
import PropTypes from 'prop-types';

import { themeProps, clutchd } from '../themed/themes';
import { getTheme } from '../themed/utils';

var propTypes = {
  theme: themeProps
};

var defaultProps = {
  theme: clutchd.theme
};

var GlobalStyle = createGlobalStyle(_templateObject);

var StyledLayout = styled.div(_templateObject2);

/**
 * The `Layout` component...
 */
var Layout = function Layout(_ref) {
  var theme = _ref.theme,
      loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['theme', 'loading', 'children']);

  var currentTheme = getTheme(ThemeContext, theme);
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(GlobalStyle, null),
    React.createElement(
      StyledLayout,
      _extends({ theme: currentTheme }, props),
      loading ? {
        /* add loading icon/skeleton component */
      } : React.createElement(
        React.Fragment,
        null,
        children
      )
    )
  );
};

Layout.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Layout.defaultProps = defaultProps;

export default Layout;

==> test-envelope-ui-0.0.40.tgz: package/es/layout/layout.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  * {\n    box-sizing: border-box;\n  }\n  #root, body, html {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n  }\n'], ['\n  * {\n    box-sizing: border-box;\n  }\n  #root, body, html {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n  }\n']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n  &&& {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n    display: flex;\n    flex-direction: column;\n    box-sizing: border-box;\n  }\n'], ['\n  &&& {\n    min-height: 100%;\n    height: 100%;\n    margin: 0;\n    padding: 0;\n    min-width: 250px;\n    width: 100%;\n    display: flex;\n    flex-direction: column;\n    box-sizing: border-box;\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React from 'react';
import styled, { createGlobalStyle, ThemeContext } from 'styled-components';
import PropTypes from 'prop-types';

import { clutchd, themeProps } from '../style/themes';
import { getTheme } from '../style/utils';

var propTypes = {
  theme: themeProps
};

var defaultProps = {
  theme: clutchd
};

var GlobalStyle = createGlobalStyle(_templateObject);

var StyledLayout = styled.div(_templateObject2);

/**
 * The `Layout` component...
 */
var Layout = function Layout(_ref) {
  var theme = _ref.theme,
      loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['theme', 'loading', 'children']);

  var currentTheme = getTheme(ThemeContext, theme);
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(GlobalStyle, null),
    React.createElement(
      StyledLayout,
      _extends({ theme: currentTheme }, props),
      loading ? {
        /* add loading icon/skeleton component */
      } : React.createElement(
        React.Fragment,
        null,
        children
      )
    )
  );
};

Layout.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Layout.defaultProps = defaultProps;

export default Layout;
